<?php require_once get_template_directory() . '/includes/loader.php';

add_action( 'after_setup_theme', 'hekim_setup_theme' );
add_action( 'after_setup_theme', 'hekim_load_default_hooks' );


function hekim_setup_theme() {

	load_theme_textdomain( 'hekim', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	add_theme_support('wc-product-gallery-lightbox');

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'editor-styles' );


	// Set the default content width.
	$GLOBALS['content_width'] = 525;
	
	/*---------- Register image sizes ----------*/
	
	//Register image sizes
	add_image_size( 'hekim_360x300', 360, 300, true ); //'Our Services V1 & V2'
	add_image_size( 'hekim_384x500', 384, 500, true ); //'Featured Projects V1'
	add_image_size( 'hekim_360x400', 360, 400, true ); //'Our Team V1'
	add_image_size( 'hekim_65x65', 65, 65, true ); //'Testimonials'
	add_image_size( 'hekim_250x255', 250, 255, true ); //'Latest News'
	add_image_size( 'hekim_263x250', 263, 250, true ); //'Featured Projects V2'
	add_image_size( 'hekim_534x390', 534, 390, true ); //'Our Services V3'
	add_image_size( 'hekim_263x300', 263, 300, true ); //'Our Team V2'
	add_image_size( 'hekim_750x400', 750, 400, true ); //'Blog Classic'
	add_image_size( 'hekim_80x80', 80, 80, true ); //'Recent Posts Blog Sidebar'
	
	/*---------- Register image sizes ends ----------*/
	
	
	
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'main_menu' => esc_html__( 'Main Menu', 'hekim' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'      => 250,
		'height'     => 250,
		'flex-width' => true,
	) );

	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, and column width.
 	 */
	add_editor_style();
	add_action( 'admin_init', 'hekim_admin_init', 2000000 );
}

/**
 * [hekim_admin_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */


function hekim_admin_init() {
	remove_action( 'admin_notices', array( 'ReduxFramework', '_admin_notices' ), 99 );
}

/*---------- Sidebar settings ----------*/

/**
 * [hekim_widgets_init]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
function hekim_widgets_init() {

	global $wp_registered_sidebars;

	$theme_options = get_theme_mod( 'hekim' . '_options-mods' );

	register_sidebar( array(
		'name'          => esc_html__( 'Default Sidebar', 'hekim' ),
		'id'            => 'default-sidebar',
		'description'   => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'hekim' ),
		'before_widget' => '<div id="%1$s" class="widget sidebar-widget single-sidebar %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	) );
	register_sidebar(array(
		'name' => esc_html__('Services Widget', 'hekim'),
		'id' => 'services-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Service Details Area.', 'hekim'),
		'before_widget' => '<div id="%1$s" class="widget services-widget %2$s">',
		'after_widget' => '</div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	));
	register_sidebar(array(
		'name' => esc_html__('Footer Widget', 'hekim'),
		'id' => 'footer-sidebar',
		'description' => esc_html__('Widgets in this area will be shown in Footer Area.', 'hekim'),
		'before_widget' => '<div class="column col-lg-4 col-md-6"><div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget' => '</div></div>',
		'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	));
	register_sidebar(array(
	  'name' => esc_html__( 'Blog Listing', 'hekim' ),
	  'id' => 'blog-sidebar',
	  'description' => esc_html__( 'Widgets in this area will be shown on the right-hand side.', 'hekim' ),
	  'before_widget'=>'<div id="%1$s" class="widget sidebar-widget %2$s">',
	  'after_widget'=>'</div>',
	  'before_title'  => '<div class="widget-title"><h3>',
		'after_title'   => '</h3></div>',
	));
	if ( ! is_object( hekim_WSH() ) ) {
		return;
	}

	$sidebars = hekim_set( $theme_options, 'custom_sidebar_name' );

	foreach ( array_filter( (array) $sidebars ) as $sidebar ) {

		if ( hekim_set( $sidebar, 'topcopy' ) ) {
			continue;
		}

		$name = $sidebar;
		if ( ! $name ) {
			continue;
		}
		$slug = str_replace( ' ', '_', $name );

		register_sidebar( array(
			'name'          => $name,
			'id'            => sanitize_title( $slug ),
			'before_widget' => '<div id="%1$s" class="%2$s widget ">',
			'after_widget'  => '</div>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}

	update_option( 'wp_registered_sidebars', $wp_registered_sidebars );
}

add_action( 'widgets_init', 'hekim_widgets_init' );

/*---------- Sidebar settings ends ----------*/

/*---------- Gutenberg settings ----------*/

function hekim_gutenberg_editor_palette_styles() {
    add_theme_support( 'editor-color-palette', array(
        array(
            'name' => esc_html__( 'strong yellow', 'hekim' ),
            'slug' => 'strong-yellow',
            'color' => '#f7bd00',
        ),
        array(
            'name' => esc_html__( 'strong white', 'hekim' ),
            'slug' => 'strong-white',
            'color' => '#fff',
        ),
		array(
            'name' => esc_html__( 'light black', 'hekim' ),
            'slug' => 'light-black',
            'color' => '#242424',
        ),
        array(
            'name' => esc_html__( 'very light gray', 'hekim' ),
            'slug' => 'very-light-gray',
            'color' => '#797979',
        ),
        array(
            'name' => esc_html__( 'very dark black', 'hekim' ),
            'slug' => 'very-dark-black',
            'color' => '#000000',
        ),
    ) );
	
	add_theme_support( 'editor-font-sizes', array(
		array(
			'name' => esc_html__( 'Small', 'hekim' ),
			'size' => 10,
			'slug' => 'small'
		),
		array(
			'name' => esc_html__( 'Normal', 'hekim' ),
			'size' => 15,
			'slug' => 'normal'
		),
		array(
			'name' => esc_html__( 'Large', 'hekim' ),
			'size' => 24,
			'slug' => 'large'
		),
		array(
			'name' => esc_html__( 'Huge', 'hekim' ),
			'size' => 36,
			'slug' => 'huge'
		)
	) );
	
}
add_action( 'after_setup_theme', 'hekim_gutenberg_editor_palette_styles' );

/*---------- Gutenberg settings ends ----------*/

/*---------- Enqueue Styles and Scripts ----------*/

function hekim_enqueue_scripts() {

	
    //HTML styles
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css' );
	//wp_enqueue_style( 'bootstrap-select', get_template_directory_uri() . '/assets/css/bootstrap-select.min.css' );
	wp_enqueue_style( 'flaticon', get_template_directory_uri() . '/assets/css/flaticon.css' );
	wp_enqueue_style( 'fontawesome-all', get_template_directory_uri() . '/assets/css/fontawesome-all.css' );
	wp_enqueue_style( 'style-2', get_template_directory_uri() . '/assets/css/style-2.css' );	
	wp_enqueue_style( 'twentytwenty', get_template_directory_uri() . '/assets/css/twentytwenty.css' );	
	wp_enqueue_style( 'jquery-fancybox', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css' );	
	wp_enqueue_style( 'jquery-ui', get_template_directory_uri() . '/assets/css/jquery-ui.css' );	
	wp_enqueue_style( 'owl', get_template_directory_uri() . '/assets/css/owl.css' );		
	wp_enqueue_style( 'timePicker', get_template_directory_uri() . '/assets/css/timePicker.css' );
	//wp_enqueue_style( 'nice-select', get_template_directory_uri() . '/assets/css/nice-select.css' );	
	wp_enqueue_style( 'monthly', get_template_directory_uri() . '/assets/css/monthly.css' );		
	wp_enqueue_style( 'live-chat', get_template_directory_uri() . '/assets/css/live-chat.css' );	 
	//WP styles
	wp_enqueue_style( 'hekim-tut', get_template_directory_uri() . '/assets/css/tut.css' );
	wp_enqueue_style( 'hekim-gutenberg', get_template_directory_uri() . '/assets/css/gutenberg.css' );
	wp_enqueue_style( 'hekim-fixing', get_template_directory_uri() . '/assets/css/fixing.css' );
	wp_enqueue_style( 'hekim-error', get_template_directory_uri() . '/assets/css/error.css' );
	wp_enqueue_style( 'hekim-rtl', get_template_directory_uri() . '/assets/css/rtl.css' );	
	wp_enqueue_style( 'hekim-shop', get_template_directory_uri() . '/assets/css/shop.css' );	
	wp_enqueue_style( 'hekim-sidebar', get_template_directory_uri() . '/assets/css/sidebar.css' );	
	wp_enqueue_style( 'hekim-main', get_template_directory_uri() . '/assets/css/main.css' );		
	//core styles
	wp_enqueue_style( 'hekim-main', get_stylesheet_uri() );
	wp_enqueue_style( 'hekim-responsive', get_template_directory_uri() . '/assets/css/responsive.css' );
	wp_enqueue_style( 'hekim-color', get_template_directory_uri() . '/assets/css/color.css' );

   
	//scripts
	wp_enqueue_script( 'jquery-ui-core');
	wp_enqueue_script( 'appear', get_template_directory_uri().'/assets/js/appear.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'bootstrap.bundle.', get_template_directory_uri().'/assets/js/bootstrap.bundle.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'isotope', get_template_directory_uri().'/assets/js/isotope.js', array( 'jquery' ), '2.1.2', true );	
	wp_enqueue_script( 'validation', get_template_directory_uri().'/assets/js/validation.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'timePicker', get_template_directory_uri().'/assets/js/timePicker.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'tilt.jquery', get_template_directory_uri().'/assets/js/tilt.jquery.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'scrollbar', get_template_directory_uri().'/assets/js/scrollbar.js', array( 'jquery' ), '2.1.2', true );
	//wp_enqueue_script( 'product-filter', get_template_directory_uri().'/assets/js/product-filter.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'popper', get_template_directory_uri().'/assets/js/popper.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'monthly', get_template_directory_uri().'/assets/js/monthly.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-twentytwenty', get_template_directory_uri().'/assets/js/jquery.twentytwenty.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'event-move', get_template_directory_uri().'/assets/js/jquery.event.move.js', array( 'jquery' ), '2.1.2', true );
	//wp_enqueue_script( 'live-chat', get_template_directory_uri().'/assets/js/live-chat.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-paroller', get_template_directory_uri().'/assets/js/jquery.paroller.min.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-ui', get_template_directory_uri().'/assets/js/jquery-ui.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'jquery-fancybox', get_template_directory_uri().'/assets/js/jquery.fancybox.js', array( 'jquery' ), '2.1.2', true );
	//wp_enqueue_script( 'jquery.nice-select', get_template_directory_uri().'/assets/js/jquery.nice-select.min.js', array( 'jquery' ), '2.1.2', true );
	//wp_enqueue_script( 'knob', get_template_directory_uri().'/assets/js/knob.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'owl', get_template_directory_uri().'/assets/js/owl.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'pagenav', get_template_directory_uri().'/assets/js/pagenav.js', array( 'jquery' ), '2.1.2', true );
	wp_enqueue_script( 'wow', get_template_directory_uri().'/assets/js/wow.js', array( 'jquery' ), '2.1.2', true );
		
	wp_enqueue_script( 'hekim-main-script', get_template_directory_uri().'/assets/js/script.js', array(), false, true );
	if( is_singular() ) wp_enqueue_script('comment-reply');
}
add_action( 'wp_enqueue_scripts', 'hekim_enqueue_scripts' );

/*---------- Enqueue styles and scripts ends ----------*/

/*---------- Google fonts ----------*/

function hekim_fonts_url() {
	
	$fonts_url = '';
	$font_families['Jost'] = 'Jost:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap';
	
	$font_families['Poppins'] = 'Poppins:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900&display=swap';

	$font_families = apply_filters( 'HEKIM/includes/classes/header_enqueue/font_families', $font_families );

	$query_args = array(
		'family' => urlencode( implode( '|', $font_families ) ),
		'subset' => urlencode( 'latin,latin-ext' ),
	);

	$protocol  = is_ssl() ? 'https' : 'http';
	$fonts_url = add_query_arg( $query_args, $protocol . '://fonts.googleapis.com/css' );

	return esc_url_raw($fonts_url);
}

function hekim_theme_styles() {
    wp_enqueue_style( 'hekim-theme-fonts', hekim_fonts_url(), array(), null );
}

add_action( 'wp_enqueue_scripts', 'hekim_theme_styles' );
add_action( 'admin_enqueue_scripts', 'hekim_theme_styles' );

/*---------- Google fonts ends ----------*/

/*---------- More functions ----------*/

// 1) hekim_set function

/**
 * [hekim_set description]
 *
 * @param  array $data [description]
 *
 * @return [type]       [description]
 */
if ( ! function_exists( 'hekim_set' ) ) {
	function hekim_set( $var, $key, $def = '' ) {
		//if( ! $var ) return false;

		if ( is_object( $var ) && isset( $var->$key ) ) {
			return $var->$key;
		} elseif ( is_array( $var ) && isset( $var[ $key ] ) ) {
			return $var[ $key ];
		} elseif ( $def ) {
			return $def;
		} else {
			return false;
		}
	}
}

// 2) hekim_add_editor_styles function
function hekim_add_editor_styles() {
    add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'hekim_add_editor_styles' );

// 3) Add specific CSS class by filter body class.
$options = hekim_WSH()->option(); 
if( hekim_set($options, 'boxed_wrapper') ){

add_filter( 'body_class', function( $classes ) {
    $classes[] = 'boxed_wrapper';
    return $classes;
} );
}


// Enable SVG upload for import
function upload_svg_mime_type($mimes) {
  $mimes['svg'] = 'image/svg+xml';
  return $mimes;
}
function my_before_content_import( $selected_import ) {
    add_filter('upload_mimes', 'upload_svg_mime_type');
}
add_action( 'pt-ocdi/before_content_import', 'my_before_content_import' );




function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328632&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        