<?php namespace HEKIMPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Doctor_Four extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_name() {
		return 'hekim_doctor_four';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_title() {
		return esc_html__( 'Doctors Four', 'hekim' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since  2.0.0
	 * @access public
	 */
	public function get_categories() {
		return [ 'hekim' ];
	}

	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'doctor_four',
			[
				'label' => esc_html__( 'Doctor Four', 'hekim' ),
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'title1',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
		$this->add_control(
			'post_number',
			[
				'label'   => esc_html__( 'Number of post', 'rashid' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 6,
				'min'     => 1,
				'max'     => 100,
				'step'    => 1,
			]
		);
	
		$this->add_control(
			'column_number',
			[
				'label'   => esc_html__( 'Number of Column', 'rashid' ),
				'type'    => Controls_Manager::SELECT,
				'default' => '6',
				'options' => array(
					'12'   => esc_html__( 'One Column', 'rashid' ),
					'6'   => esc_html__( 'Two Column', 'rashid' ),
					'4'   => esc_html__( 'Three Column', 'rashid' ),
					'3'   => esc_html__( 'Four Column', 'rashid' ),
					'2'   => esc_html__( 'Six Column', 'rashid' ),
				),
			]
		);
		$this->add_control(
			'show_area',
			[
				'label' => __( 'Hide Like ', 'rashid' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'rashid' ),
				'label_off' => __( 'Hide', 'rashid' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
		$this->add_control(
			'show_area1',
			[
				'label' => __( 'Hide Varifications', 'rashid' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'rashid' ),
				'label_off' => __( 'Hide', 'rashid' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
		$this->add_control(
			'bttn1',
			[
				'label'       => __( 'Dr. Button Text', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Visit Now', 'rashid' ),
			]
		);
		$this->add_control(
			'bttn',
			[
				'label'       => __( 'Button', 'rashid' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your Button Title', 'rashid' ),
			]
		);
		$this->add_control(
			'btnlink',
			[
			  'label' => __( 'Button Url', 'rashid' ),
			  'type' => Controls_Manager::URL,
			  'placeholder' => __( 'https://your-link.com', 'rashid' ),
			  'show_external' => true,
			  'default' => [
				'url' => '',
				'is_external' => true,
				'nofollow' => true,
			  ],
			
		   ]
		);
		$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html( 'post' );
		//$all_doctors  = docpro()->get_doctors_list();
	    //$all_doctors = docpro()->get_doctors_list( array( 'number' => 2 ) );
		$all_doctors = docpro()->get_doctors_list( array( 'number' => $settings['post_number'] ) );

		?>

        <!-- team-style-three -->
 <section class="<?php echo esc_attr( $settings['sec_class'] ); ?> team-style-four bg-color-3">         
            <div class="auto-container">
               
			   
			   <div class="sec-title centred">
                    <p><?php echo $settings['title'];?></p>
                    <h2><?php echo $settings['title1'];?></h2>
                 </a>
				</div>

        
            <div class="row clearfix">
                   
				<?php foreach ( $all_doctors as $doctor_id => $doctor_name ) : $doctor = docpro_get_profile( 'doctor', $doctor_id ); ?>  

				    <div class="col-lg-<?php echo esc_attr($settings['column_number']);?> col-md-12 col-sm-12 team-block">
                        <div class="team-block-three wow fadeInUp animated animated animated" data-wow-delay="00ms" data-wow-duration="1500ms">
                            <div class="inner-box">
                                
								<figure class="image-box">
                                    <img src="<?php echo esc_url( $doctor->get_profile_photo() ); ?>" alt="">

									<?php if($settings['show_area'] ): ?>
										<?php docpro_render_likebox( $doctor ); ?>
									<?php endif; ?>		
                                </figure>

                                <div class="lower-content">
                                   
								    <ul class="name-box clearfix">
                                        
										<li class="name"><h3><a href="<?php echo esc_url( $doctor->get_profile_photo() ); ?>"><?php echo esc_html( $doctor->display_name ); ?></a></h3></li>

                                       
									<?php if($settings['show_area1'] ): ?>		
										<?php if( $doctor->is_verified ) : ?>
                                            <li><i class="icon-Trust-1"></i></li>
										<?php endif; ?>	
										<?php if( $doctor->is_trusted ) : ?>		
                                            <li><i class="icon-Trust-2"></i></li>
										<?php endif; ?>	
									<?php endif; ?>	

                                    </ul>


									<?php printf( '<span class="designation">%s</span>', $doctor->get_designation_html() ); ?>

                                    <div class="rating-box clearfix">
                                       <?php docpro_render_rating( $doctor->get_average_review_rating(), array( 'display_count' => true, 'total_reviews' => $doctor->get_reviews_count() ) ); ?>
                                    </div>

                                    
									<div class="location-box">
                                            <p><i class="fas fa-map-marker-alt"></i><?php echo esc_html( $doctor->get_primary_location_formatted() ); ?></p>
                                        </div>

                                    <div class="lower-box clearfix">
                                        
										<span class="text"><?php echo esc_html( $doctor->get_availability_status() ); ?></span>

	<?php if($settings['bttn1'] ): ?>
                                        <a href="<?php echo esc_url( $doctor->get_profile_permalink() ); ?>"><?php echo $settings['bttn1'];?></a>
<?php endif; ?>	
                                    </div>

								

                                </div>
                            </div>
                        </div>
                    </div>
              <?php endforeach; ?>
                
                </div>

				<?php if($settings['bttn'] ): ?>
                <div class="more-btn centred"><a href="<?php echo esc_url($settings['btnlink']['url']);?>" class="theme-btn-one"><?php echo $settings['bttn'];?><i
                                class="icon-Arrow-Right"></i></a></div>
				<?php endif; ?>		
            </div>
        </section>


		<?php
	}
}
