<?php

namespace HEKIMPLUGIN\Element;

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Repeater;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;

/**
 * Elementor button widget.
 * Elementor widget that displays a button with the ability to control every
 * aspect of the button design.
 *
 * @since 1.0.0
 */
class Theme_Slider_Six extends Widget_Base {

	/**
	 * Get widget name.
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_name() {
		return 'hekim_theme_slider_six';
	}

	/**
	 * Get widget title.
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_title() {
		return esc_html__( 'Doctor Search Two', 'hekim' );
	}

	/**
	 * Get widget icon.
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since  1.0.0
	 * @access public
	 */
	public function get_icon() {
		return 'fa fa-briefcase';
	}

	/**
	 * Get widget categories.
	 * Retrieve the list of categories the button widget belongs to.
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since  2.0.0
	 * @access public
	 */
	public function get_categories() {
		return [ 'hekim' ];
	}

	/**
	 * Register button widget controls.
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function _register_controls() {
		$this->start_controls_section(
			'theme_slider_six',
			[
				'label' => esc_html__( 'Doctor Search Two', 'hekim' ),
			]
		);
		
	$this->add_control(
		'style',
		[
			'label'   => esc_html__( 'Select Style', 'rashid' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'style1',
			'options' => array(
				'style1'   => esc_html__( 'Doctor Search', 'rashid' ),
				'style2'   => esc_html__( 'Clinic Search', 'rashid' ),
		
			),
		]
	);

	
		$this->add_control(
			'bgimg',
			[
				'label'   => esc_html__( 'Background image', 'rashid' ),
				'type'    => Controls_Manager::MEDIA,
				'default' => [ 'url' => Utils::get_placeholder_image_src(), ],
			]
		);
		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter your title', 'rashid' ),
			]
		);
	
			$this->add_control(
			'sec_class',
			[
				'label'       => __( 'Section Class', 'rashid' ),
				'type'        => Controls_Manager::TEXTAREA,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'Enter Section Class', 'rashid' ),
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since  1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings     = $this->get_settings_for_display();
		$allowed_tags = wp_kses_allowed_html( 'post' );

global $docpro_query, $wp, $url_data;

$selected_dept  = docpro()->get_args_option( 'dept', '', $url_data );
$selected_loc   = docpro()->get_args_option( 'loc', '', $url_data );
$searched_name  = docpro()->get_args_option( 'n', '', $url_data );
$checked_status = docpro()->get_args_option( 'status', '', $url_data );

		?>



   <section class="<?php echo esc_attr( $settings['sec_class'] ); ?> search_six content-box">
                    <figure class="image-box"><img src="<?php echo esc_url( $settings['bgimg']['url'] ); ?>" alt=""></figure>
                    <h2><?php echo $settings['title']; ?></h2>
                 <div class="form-inner">
<?php  if ( 'style1' === $settings['style'] ) : ?>         
   <div class="big_search">                  
   <form action="<?php echo esc_url( get_the_permalink( docpro()->get_option( 'docpro_doctors_page' ) ) ); ?>" method="get" id="archive-search-form">
	<div class="select-field">
    <div class="auto-container">
        <div class="content-box">
            <div class="form-inner clearfix">
                <div class="search-fields">
                    <div class="form-group clearfix">

						<?php docpro()->pbSettings->generate_select( array( 'id' => 'dept', 'args' => docpro()->get_departments(), 'class' => 'wide docpro-filter', 'data_attr' => 'data-form=archive-search-form', 'value' => $selected_dept, 'placeholder' => esc_html__( 'Select Department', 'docpro' ) ) ); ?>

						<?php docpro()->pbSettings->generate_select( array( 'id' => 'loc', 'args' => 'POSTS_%location%', 'class' => 'wide docpro-filter', 'data_attr' => 'data-form=archive-search-form', 'value' => $selected_loc, 'placeholder' => esc_html__( 'Select Location', 'docpro' ) ) ); ?>

						<?php docpro()->pbSettings->generate_text( array( 'id' => 'n', 'placeholder' => esc_html__( 'Ex. Name..', 'docpro' ), 'value' => $searched_name ) ); ?>

                        <button type="submit"><i class="icon-Arrow-Right"></i></button>
                    </div>
                </div>
                <ul class="select-box clearfix">
                    <li>
                        <div class="single-checkbox">
                            <input class="docpro-filter" data-form="archive-search-form" type="radio" name="status" id="status-all" value="" <?php checked( $checked_status, '' ); ?>>
                            <label for="status-all"><span></span><?php esc_html_e( 'All Doctor', 'docpro' ); ?></label>
                        </div>
                    </li>
                    <li>
                        <div class="single-checkbox">
                            <input class="docpro-filter" data-form="archive-search-form" type="radio" name="status" id="status-available" value="available" <?php checked( $checked_status, 'available' ); ?>>
                            <label for="status-available"><span></span><?php esc_html_e( 'Available Doctor', 'docpro' ); ?></label>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </div>
</div>
 </form>
 </div>
<?php endif ;?>
 <?php  if ( 'style2' === $settings['style'] ) : ?>
   <div class="big_search">                  
   <form action="<?php echo esc_url( get_the_permalink( docpro()->get_option( 'docpro_clinic_page' ) ) ); ?>" method="get" id="archive-search-form">
	<div class="select-field">
    <div class="auto-container">
        <div class="content-box">
            <div class="form-inner clearfix">
                <div class="search-fields">
                    <div class="form-group clearfix">

						<?php docpro()->pbSettings->generate_select( array( 'id' => 'dept', 'args' => docpro()->get_departments(), 'class' => 'wide docpro-filter', 'data_attr' => 'data-form=archive-search-form', 'value' => $selected_dept, 'placeholder' => esc_html__( 'Select Department', 'docpro' ) ) ); ?>

						<?php docpro()->pbSettings->generate_select( array( 'id' => 'loc', 'args' => 'POSTS_%location%', 'class' => 'wide docpro-filter', 'data_attr' => 'data-form=archive-search-form', 'value' => $selected_loc, 'placeholder' => esc_html__( 'Select Location', 'docpro' ) ) ); ?>

						<?php docpro()->pbSettings->generate_text( array( 'id' => 'n', 'placeholder' => esc_html__( 'Ex. Name..', 'docpro' ), 'value' => $searched_name ) ); ?>

                        <button type="submit"><i class="icon-Arrow-Right"></i></button>
                    </div>
                </div>
                <ul class="select-box clearfix">
                    <li>
                        <div class="single-checkbox">
                            <input class="docpro-filter" data-form="archive-search-form" type="radio" name="status" id="status-all" value="" <?php checked( $checked_status, '' ); ?>>
                            <label for="status-all"><span></span><?php esc_html_e( 'All Clinic', 'docpro' ); ?></label>
                        </div>
                    </li>
                    <li>
                        <div class="single-checkbox">
                            <input class="docpro-filter" data-form="archive-search-form" type="radio" name="status" id="status-available" value="available" <?php checked( $checked_status, 'available' ); ?>>
                            <label for="status-available"><span></span><?php esc_html_e( 'Available', 'docpro' ); ?></label>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </div>
</div>
 </form>
 </div>      
         <?php endif ;?>
    
                    </div>
                </section>


		<?php
	}

}
