<?php
///----Blog widgets---
//Popular Posts
class Hekim_Recent_Posts extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Recent_Posts', /* Name */esc_html__('Hekim Recent Posts','hekim'), array( 'description' => esc_html__('Show the Recent Posts blog sidebar', 'hekim' )) );
	}
 
	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		echo wp_kses_post($before_widget); ?>
		
		<div class="post-widget">
			<?php echo wp_kses_post($before_title.$title.$after_title); ?>
			
			<div class="post-inner">
			
				<?php $query_string = 'posts_per_page='.$instance['number'];
					if( $instance['cat'] ) $query_string .= '&cat='.$instance['cat'];
					 
					$this->posts($query_string);
				?>
			</div>
			
			
		</div>
        
		<?php echo wp_kses_post($after_widget);
	}
 
 
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = $new_instance['number'];
		$instance['cat'] = $new_instance['cat'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ( $instance ) ? esc_attr($instance['title']) : esc_html__('Recent Posts', 'hekim');
		$number = ( $instance ) ? esc_attr($instance['number']) : 3;
		$cat = ( $instance ) ? esc_attr($instance['cat']) : '';?>
			
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Title: ', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('number')); ?>"><?php esc_html_e('No. of Posts:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo esc_attr( $number ); ?>" />
        </p>
       
    	<p>
            <label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php esc_html_e('Category', 'hekim'); ?></label>
            <?php wp_dropdown_categories( array('show_option_all'=>esc_html__('All Categories', 'hekim'), 'selected'=>$cat, 'class'=>'widefat', 'name'=>$this->get_field_name('categories')) ); ?>
        </p>
            
		<?php 
	}
	
	function posts($query_string)
	{
		
		$query = new WP_Query($query_string);
		if( $query->have_posts() ):?>
        
			<?php global $post;
				while( $query->have_posts() ): $query->the_post(); 
				$post_thumbnail_id = get_post_thumbnail_id($post->ID);
				$post_thumbnail_url = wp_get_attachment_url($post_thumbnail_id);
			?>
			
			<div class="post">
				<figure class="post-thumb">
					<a href="<?php echo esc_url(get_the_permalink(get_the_id()));?>">
						<?php the_post_thumbnail(); ?>
					</a>
				</figure>
				<h5><a href="<?php echo esc_url(get_the_permalink(get_the_id()));?>"><?php the_title(); ?></a></h5>
				<p><?php echo get_the_date(); ?></p>
			</div>
			
            <?php endwhile; ?>
            
        <?php endif;
		wp_reset_postdata();
    }
}

//Get In Touch
class Hekim_Get_In_Touch extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Get_In_Touch', /* Name */esc_html__('Hekim Get in Touch','hekim'), array( 'description' => esc_html__('Show the Get in Touch blog sidebar', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo wp_kses_post($before_widget); ?>
        
        <div class="contact-widget style-two">
            <div class="widget-content">
                <?php echo wp_kses_post($before_title.$title.$after_title); ?>
                <ul class="contact-info">
                	<?php if($instance['address']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-suspect"></span></div>
                        <div class="text"><?php echo wp_kses_post($instance['address']); ?></div>
                    </li>
                    <?php } ?>
                    
                    <?php if($instance['phone_number1'] or $instance['phone_number2']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-call-1"></span></div>
                        <div class="text">
                            <a href="tel:<?php echo phone_number($instance['phone_number1']); ?>"><?php echo wp_kses_post($instance['phone_number1']); ?></a> <br>
                            <a href="tel:<?php echo phone_number($instance['phone_number2']); ?>"><?php echo wp_kses_post($instance['phone_number2']); ?></a>
                        </div>
                    </li>
                    <?php } ?>
                    
                    <?php if($instance['email_address1'] or $instance['email_address2']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-chat"></span></div>
                        <div class="text">
                            <a href="mailto:<?php echo sanitize_email($instance['email_address1']); ?>"><?php echo sanitize_email($instance['email_address1']); ?></a> <br>
                            <a href="mailto:<?php echo sanitize_email($instance['email_address2']); ?>"><?php echo sanitize_email($instance['email_address2']); ?></a>
                        </div>
                    </li>
                    <?php } ?>
                </ul>
            </div>
        </div>
        
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = $new_instance['title'];
		$instance['address'] = $new_instance['address'];
		$instance['phone_number1'] = $new_instance['phone_number1'];
		$instance['phone_number2'] = $new_instance['phone_number2'];
		$instance['email_address1'] = $new_instance['email_address1'];
		$instance['email_address2'] = $new_instance['email_address2'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : '';
		$address = ($instance) ? esc_attr($instance['address']) : '';
		$phone_number1 = ($instance) ? esc_attr($instance['phone_number1']) : '';
		$phone_number2 = ($instance) ? esc_attr($instance['phone_number2']) : '';
		$email_address1 = ($instance) ? esc_attr($instance['email_address1']) : '';
		$email_address2 = ($instance) ? esc_attr($instance['email_address2']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Enter Title:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')); ?>"><?php esc_html_e('Address:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" ><?php echo wp_kses_post($address); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_number1')); ?>"><?php esc_html_e('Phone Number 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('phone_number1')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_number1')); ?>" type="text" value="<?php echo esc_attr($phone_number1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_number2')); ?>"><?php esc_html_e('Phone Number 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('phone_number2')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_number2')); ?>" type="text" value="<?php echo esc_attr($phone_number2); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_address1')); ?>"><?php esc_html_e('Email Addess 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('email_address1')); ?>" name="<?php echo esc_attr($this->get_field_name('email_address1')); ?>" type="text" value="<?php echo esc_attr($email_address1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_address2')); ?>"><?php esc_html_e('Email Addess 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('email_address2')); ?>" name="<?php echo esc_attr($this->get_field_name('email_address2')); ?>" type="text" value="<?php echo esc_attr($email_address2); ?>" />
        </p>
        
		<?php 
	}
	
}

//Call to Action
class Hekim_Call_To_Action extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Call_To_Action', /* Name */esc_html__('Hekim Call to Action','hekim'), array( 'description' => esc_html__('Show the Call to Action blog sidebar', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		echo wp_kses_post($before_widget); ?>
        
        <div class="widget_cta">
            <div class="widget-content">
                <div class="image"><img src="<?php echo esc_url($instance['image']); ?>" alt="<?php esc_attr_e('Awesome Image', 'hekim'); ?>"></div>
                <div class="content">
                    <div class="text"><?php echo wp_kses_post($instance['content']); ?></div>
                    
                    <?php if($instance['button_link'] or $instance['button_title']){ ?>
                    <a href="<?php echo esc_url($instance['button_link']); ?>" class="theme-btn btn-style-one style-three"><span><?php echo wp_kses_post($instance['button_title']); ?></span></a>
                    <?php } ?>
                </div>
            </div>
        </div>
        
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['image'] = strip_tags($new_instance['image']);
		$instance['content'] = $new_instance['content'];
		$instance['button_title'] = $new_instance['button_title'];
		$instance['button_link'] = $new_instance['button_link'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$image = ($instance) ? esc_attr($instance['image']) : get_template_directory_uri().'/assets/images/resource/news-16.jpg';
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$button_title = ($instance) ? esc_attr($instance['button_title']) : '';
		$button_link = ($instance) ? esc_attr($instance['button_link']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('image')); ?>"><?php esc_html_e('Logo Image URL:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('image')); ?>" name="<?php echo esc_attr($this->get_field_name('image')); ?>" type="text" value="<?php echo esc_attr($image); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('content')); ?>"><?php esc_html_e('Content:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_title')); ?>"><?php esc_html_e('Button Title:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('button_title')); ?>" name="<?php echo esc_attr($this->get_field_name('button_title')); ?>" type="text" value="<?php echo esc_attr($button_title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('button_link')); ?>"><?php esc_html_e('Button URL:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('button_link')); ?>" name="<?php echo esc_attr($this->get_field_name('button_link')); ?>" type="text" value="<?php echo esc_attr($button_link); ?>" />
        </p>
        
		<?php 
	}
}

///----Service Sidebar widgets---
//Our Broucher
class Hekim_Our_Broucher extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Our_Broucher', /* Name */esc_html__('Hekim Our Broucher','hekim'), array( 'description' => esc_html__('Show the Our Broucher in services sidebar.', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		echo wp_kses_post($before_widget); ?>
        
        <div class="widget_brochure">
            <div class="widget-content">                                
                <?php if($instance['broucher_title1'] and $instance['broucher_link1']){ ?>
                <div class="single-brochure"><div class="icon"><img src="<?php echo get_template_directory_uri(); ?>/assets/images/icons/icon-29.png" alt="<?php esc_attr_e('Icon', 'hekim'); ?>"></div><a href="<?php echo esc_url($instance['broucher_link1']); ?>"><?php echo wp_kses_post($instance['broucher_title1']); ?></a></div>
                <?php } ?>
                
                <?php if($instance['broucher_title2'] and $instance['broucher_link2']){ ?>
                <div class="single-brochure"><div class="icon"><img src="<?php echo get_template_directory_uri(); ?>/assets/images/icons/icon-30.png" alt="<?php esc_attr_e('Icon', 'hekim'); ?>"></div><a href="<?php echo esc_url($instance['broucher_link2']); ?>"><?php echo wp_kses_post($instance['broucher_title2']); ?></a></div>
                <?php } ?>
            </div>
        </div>
        
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['broucher_title1'] = $new_instance['broucher_title1'];
		$instance['broucher_link1'] = $new_instance['broucher_link1'];
		$instance['broucher_title2'] = $new_instance['broucher_title2'];
		$instance['broucher_link2'] = $new_instance['broucher_link2'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$broucher_title1 = ($instance) ? esc_attr($instance['broucher_title1']) : esc_html__('Download Brochure', 'hekim');
		$broucher_link1 = ($instance) ? esc_attr($instance['broucher_link1']) : '#';
		$broucher_title2 = ($instance) ? esc_attr($instance['broucher_title2']) : esc_html__('About Hekim', 'hekim');
		$broucher_link2 = ($instance) ? esc_attr($instance['broucher_link2']) : '#';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_title1')); ?>"><?php esc_html_e('Broucher Title 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('broucher_title1')); ?>" name="<?php echo esc_attr($this->get_field_name('broucher_title1')); ?>" type="text" value="<?php echo esc_attr($broucher_title1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_link1')); ?>"><?php esc_html_e('Broucher URL 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('broucher_link1')); ?>" name="<?php echo esc_attr($this->get_field_name('broucher_link1')); ?>" type="text" value="<?php echo esc_attr($broucher_link1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_title2')); ?>"><?php esc_html_e('Broucher Title 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('broucher_title2')); ?>" name="<?php echo esc_attr($this->get_field_name('broucher_title2')); ?>" type="text" value="<?php echo esc_attr($broucher_title2); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_link2')); ?>"><?php esc_html_e('Broucher URL 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('broucher_link2')); ?>" name="<?php echo esc_attr($this->get_field_name('broucher_link2')); ?>" type="text" value="<?php echo esc_attr($broucher_link2); ?>" />
               
		<?php 
	}
	
}

//Request a Free Quote
class Hekim_Request_a_Free_Quote extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Request_a_Free_Quote', /* Name */esc_html__('Hekim Request a Free Quote','hekim'), array( 'description' => esc_html__('Show the Our Broucher in services sidebar.', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo wp_kses_post($before_widget); ?>
        
        <div class="widget_contact-form">
            <?php echo wp_kses_post($before_title.$title.$after_title); ?>
            <div class="text"><?php echo wp_kses_post($instance['content']); ?></div>
            <?php echo do_shortcode($instance['form_shortcode']); ?>
        </div>
        
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = $new_instance['title'];
		$instance['content'] = $new_instance['content'];
		$instance['form_shortcode'] = $new_instance['form_shortcode'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : esc_html__('Request a Free Quote', 'hekim');
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$form_shortcode = ($instance) ? esc_attr($instance['form_shortcode']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Enter Title:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_link1')); ?>"><?php esc_html_e('Content:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('broucher_title2')); ?>"><?php esc_html_e('Form Shortcode:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('form_shortcode')); ?>" name="<?php echo esc_attr($this->get_field_name('form_shortcode')); ?>" ><?php echo wp_kses_post($form_shortcode); ?></textarea>
        </p>
        
		<?php 
	}
}

///----Footer Widgets---
//About Us
class Hekim_About_Us extends WP_Widget
{
	
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_About_Us', /* Name */esc_html__('Hekim About Us','hekim'), array( 'description' => esc_html__('Show the About Us in footer', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		echo wp_kses_post($before_widget);?>
      		
            <div class="about-widget">
                <div class="logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><img src="<?php echo esc_url($instance['logo_image']); ?>" alt="<?php esc_attr_e('Logo', 'hekim'); ?>" /></a></div>
                <div class="text"><?php echo wp_kses_post($instance['content']); ?></div>
                
                <?php if( $instance['show'] ): ?>
                <?php echo wp_kses_post(hekim_get_social_icons2()); ?>
                <?php endif; ?>
            </div>
            
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['logo_image'] = strip_tags($new_instance['logo_image']);
		$instance['content'] = $new_instance['content'];
		$instance['show'] = $new_instance['show'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$logo_image = ($instance) ? esc_attr($instance['logo_image']) : get_template_directory_uri().'/assets/images/logo-two.png';
		$content = ($instance) ? esc_attr($instance['content']) : '';
		$show = ($instance) ? esc_attr($instance['show']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('logo_image')); ?>"><?php esc_html_e('Logo Image URL:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('logo_image')); ?>" name="<?php echo esc_attr($this->get_field_name('logo_image')); ?>" type="text" value="<?php echo esc_attr($logo_image); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('content')); ?>"><?php esc_html_e('Content:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('content')); ?>" name="<?php echo esc_attr($this->get_field_name('content')); ?>" ><?php echo wp_kses_post($content); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('show')); ?>"><?php esc_html_e('Show Social Icons:', 'hekim'); ?></label>
			<?php $selected = ( $show ) ? ' checked="checked"' : ''; ?>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('show')); ?>"<?php echo esc_attr($selected); ?> name="<?php echo esc_attr($this->get_field_name('show')); ?>" type="checkbox" value="true" />
        </p>
        
<?php 
	}
	
}

//Get In Touch Footer
class Hekim_Get_In_Touch_Footer extends WP_Widget
{
	/** constructor */
	function __construct()
	{
		parent::__construct( /* Base ID */'Hekim_Get_In_Touch_Footer', /* Name */esc_html__('Hekim Get in Touch Footer','hekim'), array( 'description' => esc_html__('Show the Get in Touch in footer.', 'hekim' )) );
	}

	/** @see WP_Widget::widget */
	function widget($args, $instance)
	{
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		echo wp_kses_post($before_widget); ?>
        
        <div class="contact-widget">
			<?php echo wp_kses_post($before_title.$title.$after_title); ?>
            <div class="widget-content">
                <ul class="contact-info">
                	<?php if($instance['address']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-suspect"></span></div>
                        <div class="text"><?php echo wp_kses_post($instance['address']); ?></div>
                    </li>
                    <?php } ?>
                    
                    <?php if($instance['phone_number1'] or $instance['phone_number2']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-call-1"></span></div>
                        <div class="text">
                            <a href="tel:<?php echo phone_number($instance['phone_number1']); ?>"><?php echo wp_kses_post($instance['phone_number1']); ?></a> <br>
                            <a href="tel:<?php echo phone_number($instance['phone_number2']); ?>"><?php echo wp_kses_post($instance['phone_number2']); ?></a>
                        </div>
                    </li>
                    <?php } ?>
                    
                    <?php if($instance['email_address1'] or $instance['email_address2']){ ?>
                    <li>
                        <div class="icon"><span class="flaticon-chat"></span></div>
                        <div class="text">
                            <a href="mailto:<?php echo sanitize_email($instance['email_address1']); ?>"><?php echo sanitize_email($instance['email_address1']); ?></a> <br>
                            <a href="mailto:<?php echo sanitize_email($instance['email_address2']); ?>"><?php echo sanitize_email($instance['email_address2']); ?></a>
                        </div>
                    </li>
                    <?php } ?>
                </ul>
            </div>
        </div>
        
        <?php
		
		echo wp_kses_post($after_widget);
	}
	
	
	/** @see WP_Widget::update */
	function update($new_instance, $old_instance)
	{
		$instance = $old_instance;
		
		$instance['title'] = $new_instance['title'];
		$instance['address'] = $new_instance['address'];
		$instance['phone_number1'] = $new_instance['phone_number1'];
		$instance['phone_number2'] = $new_instance['phone_number2'];
		$instance['email_address1'] = $new_instance['email_address1'];
		$instance['email_address2'] = $new_instance['email_address2'];
		
		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance)
	{
		$title = ($instance) ? esc_attr($instance['title']) : '';
		$address = ($instance) ? esc_attr($instance['address']) : '';
		$phone_number1 = ($instance) ? esc_attr($instance['phone_number1']) : '';
		$phone_number2 = ($instance) ? esc_attr($instance['phone_number2']) : '';
		$email_address1 = ($instance) ? esc_attr($instance['email_address1']) : '';
		$email_address2 = ($instance) ? esc_attr($instance['email_address2']) : '';
		?>
        
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>"><?php esc_html_e('Enter Title:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('address')); ?>"><?php esc_html_e('Address:', 'hekim'); ?></label>
            <textarea class="widefat" id="<?php echo esc_attr($this->get_field_id('address')); ?>" name="<?php echo esc_attr($this->get_field_name('address')); ?>" ><?php echo wp_kses_post($address); ?></textarea>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_number1')); ?>"><?php esc_html_e('Phone Number 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('phone_number1')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_number1')); ?>" type="text" value="<?php echo esc_attr($phone_number1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_number2')); ?>"><?php esc_html_e('Phone Number 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('phone_number2')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_number2')); ?>" type="text" value="<?php echo esc_attr($phone_number2); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_address1')); ?>"><?php esc_html_e('Email Addess 1:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('email_address1')); ?>" name="<?php echo esc_attr($this->get_field_name('email_address1')); ?>" type="text" value="<?php echo esc_attr($email_address1); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_address2')); ?>"><?php esc_html_e('Email Addess 2:', 'hekim'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('email_address2')); ?>" name="<?php echo esc_attr($this->get_field_name('email_address2')); ?>" type="text" value="<?php echo esc_attr($email_address2); ?>" />
        </p>
        
		<?php 
	}
	
}